@@ -1,7 +1,7 @@
 package App::Monport;
 use App::Cmd::Setup -app;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -37,12 +37,29 @@ To install this module, run:
 
  $ cpanm App::Monport
 
- when using L<App::cpanminus>. Of course you can use your favorite CPAN client
- or install manually by cloning the L</"SOURCE REPOSITORY"> and then running:
+when using L<App::cpanminus>. Of course you can use your favorite CPAN client
+or install manually by cloning the L</"SOURCE REPOSITORY"> and then running:
 
  perl Build.PL
  ./Build
  ./Build test
  ./Build install
 
+=head1 SOURCE REPOSITORY
+
+L<http://github.com/jreisinger/App-Monport>
+
+=head1 AUTHOR
+
+Jozef Reisinger, E<lt>reisinge@cpan.orgE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2015 by Jozef Reisinger
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
+
 1;
